#!/bin/sh

cd $(dirname $0)
SCRIPTDIR=$(pwd)
echo $SCRIPTDIR

export DISPLAY=:0

ulimit -c unlimited

# Set the screen resolution but avoid writing if not needed. Resolution may have changed for two reasons:
# 1. Files came from a cloned data partition of a different device
# 2. Screen orientation changed ( portrait/landscape )

SCREEN_RES="$( DISPLAY=:0 xdpyinfo 2> /dev/null | grep dimensions: | awk '{print $2}' )"
SCREEN_X="$( echo $SCREEN_RES | cut -dx -f1 )"
SCREEN_Y="$( echo $SCREEN_RES | cut -dx -f2 )"
CURR_SCREEN_X="$( cat CODESYSControl.cfg | grep WindowSizeWidth | cut -d= -f2 | xargs )"
CURR_SCREEN_Y="$( cat CODESYSControl.cfg | grep WindowSizeHeight | cut -d= -f2 | xargs )"

if [ ! "$CURR_SCREEN_X" = "$SCREEN_X" -o ! "$CURR_SCREEN_Y" = "$SCREEN_Y" ]; then

	if ! ( cat CODESYSControl.cfg | grep -q '\[CmpTargetVisu\]' ); then
		echo >> CODESYSControl.cfg
		echo "[CmpTargetVisu]" >> CODESYSControl.cfg
	fi

	sed -i '/WindowPositionX=/d' CODESYSControl.cfg
	sed -i '/WindowPositionY=/d' CODESYSControl.cfg
	sed -i '/WindowSizeWidth=/d' CODESYSControl.cfg
	sed -i '/WindowSizeHeight=/d' CODESYSControl.cfg
	sed -i "s:\[CmpTargetVisu\]:\[CmpTargetVisu\]\nWindowPositionX=0\nWindowPositionY=0\nWindowSizeWidth=${SCREEN_X}\nWindowSizeHeight=${SCREEN_Y}:" CODESYSControl.cfg
	sync
fi

if [ -e "/mnt/data/hmi/restorecdsdefault.bin" ]; then
	rm -rf PlcLogic
	[ -e "/dev/fram" ] && dd if=/dev/zero of=/dev/fram bs=1024 count=64
	rm -rf /mnt/data/hmi/restorecdsdefault.bin
	sync
fi

LD_LIBRARY_PATH=$SCRIPTDIR:.:$LD_LIBRARY_PATH \
PATH=$SCRIPTDIR:$PATH \
QTDIR=$SCRIPTDIR \
QT_PLUGIN_PATH=$SCRIPTDIR/plugin:$SCRIPTDIR:$SCRIPTDIR/imageformats \
./codesyscontrol

if ls core* 2> /dev/null ; then
	mkdir -p var/log
	mkdir -p preserved
	mv `find var/log -iname '*crashlog.tar' | sort | tail -n 3` ./preserved
	rm var/log/*crashlog.tar 2> /dev/null
	mv ./preserved/* var/log 2> /dev/null
	rm -rf preserved
	mkdir -p gdbcoredumps
	mv core* gdbcoredumps
	tar chvzf gdbcoredumps/logs.tar.gz /var/log/
	cp ../../jmlauncher.xml  gdbcoredumps
	cp var/log/*.log gdbcoredumps
	cp var/log/*.txt gdbcoredumps
	tar cvzf var/log/`date +%Y%m%d%H%M%S`-crashlog.tar.gz gdbcoredumps
	rm -rf gdbcoredumps
	sync
fi
